# -*- coding: utf-8 -*-

from django import template


register = template.Library()
from django.conf import settings

"""
AMIGUITO  = u"1273360443" # Iñaki
LINK      = u"http://fo.dev.binomia.es/facebook/movies/detail/what-doesnt-kill-you/"
PICTURE   = u"http://fo.dev.binomia.es/media/images/movies/W/what_doesn_t_kill_you.jpg"
NAME      = u"What doesn't kill you?"
CAPTION   = u"filmsobsession.com"
DESC      = u"Dos amigos de los barrios bajos del sur de Boston se convierten en delincuentes de poca monta hasta que son contratados por un jefe mafioso que podría abrirles las puertas de un mundo mejor."
ACTION    = u"[{name: 'ver online', link: 'http://www.google.es'}]"

FACEBOOK_FEED_URL = "https://www.facebook.com/dialog/feed?app_id=%s&to=%s&actions=[{name:'%s',link:'%s'}]&link=%s&picture=%s&name=%s&caption=%s&description=%s&redirect_uri=%s&display=popup" % (
                        FACEBOOK_APP_ID, AMIGUITO, ACTION, LINK, PICTURE, NAME, CAPTION, DESC, FACEBOOK_REDIRECT_URL)

"""


@register.simple_tag(takes_context=True)
def facebook_feed_url(context, friend, link, picture, name, caption, description, action_name, action_link, redirect_uri):
    
    request = context['request']
    
    faceboo_app_id = settings.FACEBOOK_APP_ID
    
    return "https://www.facebook.com/dialog/feed?app_id=%s&to=%s&actions=[{name:'%s',link:'%s'}]&link=%s&picture=%s&name=%s&caption=%s&description=%s&redirect_uri=%s&display=popup" % (
                        faceboo_app_id, friend, action_name, action_link, link, picture, name, caption, description, redirect_uri)




# -*- encoding: utf-8 -*-

from django.contrib.auth.models import User
from models import UserProfile

import logging
import facebook

logger = logging.getLogger(__name__)

class FacebookBackend:
    
    """
        Token based authentication
    """
    def authenticate(self, token=None):        
        
        # Create an instance of facebook API centered in the user node.
        graph = facebook.GraphAPI(token)
    
        # Ask fb the user info.
        profile = graph.get_object("me")
        logger.debug(profile)
        
        #Obtains fb user id.
        uid = profile["id"]
            
        try:
            # try to get a user based on fb uid stored in db.
            userProfile = UserProfile.objects.get(uid=uid)
            
            #Update token
            userProfile.access_token = token
            
            """
            TODO: falta por actualizar la fecha de expiración del token.
            """
            
            userProfile.save()
        
            logger.debug("Encontrado userProfile: %s" % userProfile.user.username)
            return userProfile.user
        
        except UserProfile.DoesNotExist:
            user = User()
            user.set_unusable_password()
            user.email = profile['email']
            user.username = uid
            user.first_name = profile['first_name']
            user.last_name = profile['last_name']
            user.save()
            
            
            userProfile = UserProfile()
            userProfile.user = user;
            userProfile.access_token = token
            userProfile.uid = profile["id"]
            
            userProfile.save()
            logger.debug("Creado userProfile: %s" % user)
            return user
          
        # Never reached.  
        return user
   
   
    def get_user(self, user_id):
        try:
            return User.objects.get(pk=user_id)
        except User.DoesNotExist:
            return None
        


from django.contrib import auth
from django.conf import settings
from facebook import parse_signed_request


import logging


logger = logging.getLogger(__name__)


def facebook_canvas_index(view):
    """
    This decorator should be applied to the facebook access point view.
    """
    def decorated(*args, **kwargs):
        logger.debug("Cargando decorador 'facebook_canvas_index'")
        request = args[0]
        
        try:
            #Get signed_request sent by facebook
            signed_request = request.POST["signed_request"]
            #Decode of singed request with the FACEBOOK_APP_SECRET
            parsed_request = parse_signed_request(signed_request, settings.FACEBOOK_APP_SECRET)
            
            logger.debug("signed_request: %s" % signed_request)
            logger.debug("parsed_request: %s" % parsed_request)
            
            #Try to authenticate the user with the authbackends
            #Eventually the backend django_facebook_helper.FacebookBackend will authenticate this User
            user = auth.authenticate(token=parsed_request["oauth_token"])
            logger.debug("user: %s" % user)
            
            if user is not None:
                if user.is_active:
                    auth.login(request, user)
                    # Redirect to a success page.
                else:
                    pass # Return a 'disabled account' error message
            else:
                # Return an 'invalid login' error message.
                pass
        except:
            pass
        
        return view(*args, **kwargs)
    
    return decorated


import os
from setuptools import setup

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "django_facebook_helper",
    packages=['django_facebook_helper', 'tests'],
    version = "0.2.6",
    include_package_data = True,
    author = "Samuel Barrado",
    author_email = "samuel.barrado@gmail.com",
    description = ("A Django application for helping in facebook login an managing."),
    license = "BSD",
    keywords = "django facebook",
    url = "http://packages.python.org/django_facebook_helper",
    long_description=read('README'),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: BSD License",
    ],
)